# Contributing

## Introduction

At the moment Hike is still pretty early in its development, so I'm unlikely
to accept PRs unless they're for very trivial issues. It's not that I won't
accept code from others, it's just that I'm still in the *"let's see where
this takes me"* stage of development with the application.

However, I'm very happy to receive feedback, suggestions and bug reports.

## Feedback and suggestions

The best place for feedback and suggestions is [in
discussions](https://github.com/davep/hike/discussions). If it seems
like something that makes sense for Hike I'll turn it into an issue
from there.

Be sure to [have a look over the TODO
isues](https://github.com/davep/hike/issues?q=is%3Aissue+is%3Aopen+label%3ATODO)
before leaving a request, it might be I'm already planning on implementing
whatever it is you're asking for.

## Bugs

Please report any bugs [as an
issue](https://github.com/davep/hike/issues). When doing so, please
provide as much detail as possible, include things like Hike version,
operating system, some details of the environment, etc.

[//]: # (CONTRIBUTING.md ends here)
